@@ -456,7 +456,7 @@ generate_actions_box (GnomeFilePropertyDialog *fp_dlg)
 
 	/* Here's the Logic: */
 	/* All tops of files (other then folders) should let us edit "open" */
-	/* If we are a file, and an executable, we want to edit our "drop-target" */
+	/* If we are a file, and an executable, we want to edit our "drop-action" */
 	/* Metadata, as it is meaningful to us.  */
 	/* If we are non-executable, we want to edit our "edit" and "view" fields. */
 	/* Sym links want to have the same options as above, but use their Target's */
@@ -569,7 +569,8 @@ create_settings_pane (GnomeFilePropertyDialog *fp_dlg)
 	GtkWidget *align;
 	GtkWidget *table;
 	struct stat linkstat;
-
+	int finish;
+	
 	vbox = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), GNOME_PAD);
 
@@ -591,7 +592,16 @@ create_settings_pane (GnomeFilePropertyDialog *fp_dlg)
 	if (S_ISLNK (fp_dlg->st.st_mode))
 		mc_stat (fp_dlg->file_name, &linkstat);
 
-	if (!(S_ISREG (fp_dlg->st.st_mode) || (S_ISLNK (fp_dlg->st.st_mode) && !S_ISREG (linkstat.st_mode)))) {
+	finish = 0;
+	if (!S_ISREG (fp_dlg->st.st_mode)){
+		if (S_ISLNK (fp_dlg->st.st_mode)){
+			if (!S_ISREG (linkstat.st_mode))
+				finish = 1;
+		} else
+			finish = 1;
+	}
+
+	if (finish){
 		if (!fp_dlg->can_set_icon) {
 			gtk_widget_unref (vbox);
 			vbox = NULL;
@@ -826,10 +836,15 @@ perm_group_new (GnomeFilePropertyDialog *fp_dlg)
 	if ((fp_dlg->euid == 0) || (fp_dlg->st.st_uid == fp_dlg->euid)) {
 		gentry = gtk_combo_new ();
 		grp = getgrgid (fp_dlg->st.st_gid);
-		if (grp->gr_name)
-			fp_dlg->group_name = g_strdup (grp->gr_name);
-		else {
-			sprintf (grpnum, "%d", (int) grp->gr_gid);
+		if (grp){
+			if (grp->gr_name)
+				fp_dlg->group_name = g_strdup (grp->gr_name);
+			else {
+				sprintf (grpnum, "%d", (int) grp->gr_gid);
+				fp_dlg->group_name = g_strdup (grpnum);
+			}
+		} else {
+			sprintf (grpnum, "%d", (int) fp_dlg->st.st_gid);
 			fp_dlg->group_name = g_strdup (grpnum);
 		}
 
@@ -842,7 +857,11 @@ perm_group_new (GnomeFilePropertyDialog *fp_dlg)
 				sprintf (grpnum, "%d", (int) grp->gr_gid);
 				grpname = grpnum;
 			}
+		} else {
+			sprintf (grpnum, "%d", (int) grp->gr_gid);
+			grpname = grpnum;
 		}
+			
 		if (fp_dlg->euid != 0)
 			gtk_editable_set_editable (GTK_EDITABLE (GTK_COMBO (gentry)->entry), FALSE);
 		for (setgrent (); (grp = getgrent ()) != NULL;) {
@@ -876,8 +895,7 @@ perm_group_new (GnomeFilePropertyDialog *fp_dlg)
 		for (templist = list; templist; templist = templist->next) {
 			g_free (templist->data);
 		}
-		grp = getgrgid (fp_dlg->st.st_gid);
-		gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (gentry)->entry), grp->gr_name);
+		gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (gentry)->entry), grpname);
 		g_list_free (list);
 	} else {
 		/* we're neither so we just put an entry down */
@@ -963,7 +981,7 @@ init_metadata (GnomeFilePropertyDialog *fp_dlg)
 	if (gnome_metadata_get (fp_dlg->file_name, "fm-view", &size, &fp_dlg->fm_view) != 0)
 		gnome_metadata_get (fp_dlg->file_name, "view", &size, &fp_dlg->fm_view);
 	gnome_metadata_get (fp_dlg->file_name, "edit", &size, &fp_dlg->edit);
-	gnome_metadata_get (fp_dlg->file_name, "drop-target", &size, &fp_dlg->drop_target);
+	gnome_metadata_get (fp_dlg->file_name, "drop-action", &size, &fp_dlg->drop_target);
 
 	/*
 	 * Fetch the needs-terminal setting
@@ -1005,7 +1023,7 @@ init_metadata (GnomeFilePropertyDialog *fp_dlg)
 	if (!fp_dlg->mime_fm_view)
 		fp_dlg->mime_fm_view = gnome_mime_get_value (mime_type, "view");
 	fp_dlg->mime_edit = gnome_mime_get_value (mime_type, "edit");
-	fp_dlg->mime_drop_target = gnome_mime_get_value (mime_type, "drop-target");
+	fp_dlg->mime_drop_target = gnome_mime_get_value (mime_type, "drop-action");
 
 	gnome_metadata_get (fp_dlg->file_name, "icon-filename", &size, &fp_dlg->icon_filename);
 	if (fp_dlg->icon_filename)
@@ -1239,16 +1257,16 @@ apply_metadata_change (GnomeFilePropertyDialog *fpd)
 				text = gtk_entry_get_text (GTK_ENTRY (fpd->prop1_entry));
 				if (text && text[0])
 					gnome_metadata_set (fpd->file_name,
-							    "drop-target",
+							    "drop-action",
 							    strlen (text) + 1,
 							    text);
 				else
 					gnome_metadata_remove (fpd->file_name,
-							       "drop-target");
+							       "drop-action");
 			} else {
 				if (fpd->drop_target)
 					gnome_metadata_remove (fpd->file_name,
-							       "drop-target");
+							       "drop-action");
 			}
 		} else {
 			if (!GTK_TOGGLE_BUTTON (fpd->prop1_cbox)->active) {
