@@ -34,7 +34,8 @@ enum {
 	F_PANEL		= 1 << 6,       /* Applies to files from a panel window */
 	F_MOUNTABLE     = 1 << 7,       /* Only if the device is mountable */
 	F_UNMOUNTABLE   = 1 << 8,       /* Only if the device is unmountable */
-	F_EJECTABLE     = 1 << 9        /* Only if the device is ejectable */
+	F_EJECTABLE     = 1 << 9,       /* Only if the device is ejectable */
+	F_LOCAL         = 1 << 10       /* File must be on a local file system */
 };
 
 struct action {
@@ -260,9 +261,9 @@ static struct action file_actions[] = {
 	{ N_("Unmount device"),  F_SINGLE|F_UNMOUNTABLE|F_DICON, (GtkSignalFunc) dicon_unmount },
 	{ N_("Eject device"),    F_SINGLE|F_EJECTABLE|F_DICON,   (GtkSignalFunc) dicon_eject },
 	{ "",                    F_SINGLE,   	    	  	 NULL },
-	{ N_("Open"),            F_PANEL | F_ALL,      	  	 (GtkSignalFunc) panel_action_open },
-	{ N_("Open"),            F_DICON | F_ALL, 	  	 (GtkSignalFunc) dicon_execute },
-	{ N_("Open with"),       F_PANEL | F_ALL,      	  	 (GtkSignalFunc) panel_action_open_with },
+	{ N_("Open"),            F_LOCAL| F_PANEL | F_ALL,	 (GtkSignalFunc) panel_action_open },
+	{ N_("Open"),            F_LOCAL | F_DICON | F_ALL, 	 (GtkSignalFunc) dicon_execute },
+	{ N_("Open with"),       F_LOCAL | F_PANEL | F_ALL, 	 (GtkSignalFunc) panel_action_open_with },
 	{ N_("View"),            F_PANEL | F_NOTDIR,      	 (GtkSignalFunc) panel_action_view },
 	{ N_("View unfiltered"), F_PANEL | F_NOTDIR,      	 (GtkSignalFunc) panel_action_view_unfiltered },  
 	{ N_("Edit"),            F_PANEL | F_NOTDIR,             (GtkSignalFunc) panel_action_edit },
@@ -482,19 +483,35 @@ mime_command_from_panel (GtkMenuItem *item, WPanel *panel)
 static void
 mime_command_from_desktop_icon (GtkMenuItem *item, char *filename)
 {
-	char *action;
-	int movedir;
-	char *key;
-	const char *mime_type, *val;;
-	action = get_label_text (item);
+	char *action, *buf;
+	int movedir, size;
+	char *key, *flag_key;
+	const char *mime_type, *val, *flags;
+	int needs_terminal = 0;
 
+	action = get_label_text (item);
+	
 	key = gtk_object_get_user_data (GTK_OBJECT (item));
 	mime_type = gnome_mime_type_or_default (filename, NULL);
 	if (!mime_type)
 		return;
+
+	/*
+	 * Find out if we need to run this in a terminal
+	 */
+	if (gnome_metadata_get (filename, "flags", &size, &buf) == 0){
+		needs_terminal = strstr (flags, "needsterminal") != 0;
+		g_free (buf);
+	} else {
+		flag_key = g_strconcat ("flags.", key, "flags", NULL);
+		flags = gnome_mime_get_value (filename, flag_key);
+		g_free (flag_key);
+		if (flags)
+			needs_terminal = strstr (flags, "needsterminal") != 0;
+	}
 	
 	val = gnome_mime_get_value (mime_type, key);
-	exec_extension (filename, val, NULL, NULL, 0);
+	exec_extension (filename, val, NULL, NULL, 0, needs_terminal);
 }
 
 /* Create the menu items common to files from panel window and desktop icons, and also the items for
