@@ -79,7 +79,7 @@ typedef struct {
 extern sort_orders_t sort_orders [SORT_TYPES_TOTAL];
 
 int link_isdir (file_entry *);
-int if_link_is_exe (file_entry *file);
+int if_link_is_exe (char *directory, file_entry *file);
 
 extern int show_backups;
 extern int show_dot_files;
