@@ -76,7 +76,7 @@
 #include "user.h"		/* expand_format */
 #include "../vfs/vfs.h"
 
-/* "$Id: util.c,v 1.18 1999/02/13 20:12:52 unammx Exp $" */
+/* "$Id: util.c,v 1.19 1999/02/24 21:26:50 unammx Exp $" */
 
 char app_text [] = "Midnight-Commander";
 
@@ -776,6 +776,16 @@ char *strip_ctrl_codes (char *s)
 
 #endif /* VFS_STANDALONE */
 
+/*
+ * Ok, on systems running glibc, getcwd does not use popen pwd on
+ * Linux at least
+ */
+#ifdef __GLIBC__
+#  ifdef linux
+#     undef HAVE_GETWD
+#  endif
+#endif
+
 /* getwd is better than getcwd, the later uses a popen ("pwd"); */
 char *get_current_wd (char *buffer, int size)
 {
