@@ -283,13 +283,19 @@ int my_system (int flags, const char *shell, const char *command)
 
 #ifdef USE_VFS
 	if (flags & EXECUTE_SETUID)
+#    if defined (HAVE_SETUID)
+	    setuid (vfs_uid);
+#    elif defined (HAVE_SETREUID)
 	    setreuid (vfs_uid, vfs_uid);
+#    else
+	    ; /* Can't drop privileges */
+#    endif
 #endif
 	
 	if (flags & EXECUTE_AS_SHELL)
-	    execl (shell, shell, "-c", command, (char *) 0);
+	    execl (shell, shell, "-c", command, NULL);
 	else
-	    execlp (shell, shell, command, (char *) 0);
+	    execlp (shell, shell, command, NULL);
 
 	_exit (127);		/* Exec error */
     } else {
